# Copyright (c) 2022 ANSYS, Inc. - Unauthorised use, distribution or duplication is prohibited.

from ansys.report.engine.protos.report_pb2 import File, Image, ImageSize, Size

from .report_fixed_size_type import ReportFixedSizeType
from .report_units import ReportUnits


class ReportImage:
    def __init__(self, image_file_path, width, caption=""):
        """
        Constructs all the necessary attributes for the image object.

        Parameters
        ----------
            image_file_path : str
                Image file path.
            width : float
                Image width in centimeter.
            caption : str
                Optional - Image caption.
        """
        self.path = image_file_path
        self.caption = caption
        self.set_width_in_centimeter(width)

    @property
    def unit(self):
        """
        Read only - unit definition for image width.
        """
        return self._unit

    def set_width_in_centimeter(self, width):
        """
        Set the image width in centimeter.

        Parameters
        ----------
        width: float
           Image width in centimeter.
        """
        self._unit = ReportUnits.CENTIMETER.value
        self._width = width

    def _to_proto_image(self, id):
        proto_image = Image()

        proto_image.parent_id.CopyFrom(id)

        image_file_path = File()
        image_file_path.path = self.path
        proto_image.image_file_path.CopyFrom(image_file_path)

        proto_image.caption = self.caption

        image_image_size = ImageSize()
        image_size_width = Size()
        image_size_width.unit = self._unit
        image_size_width.value = self._width
        image_image_size.width.CopyFrom(image_size_width)

        proto_image.size.CopyFrom(image_image_size)
        proto_image.size.fixed_size_type = ReportFixedSizeType.WIDTH.value

        return proto_image
