# Copyright (c) 2022 ANSYS, Inc. - Unauthorised use, distribution or duplication is prohibited.

import functools
import logging
import logging.config
import os

import grpc

LOGGER_NAME = "ReportGenerator"
LOGGER_CONFIG_FILE = "report_logger.config"


class ReportLogger:
    def __enter__(self):
        return self

    def __del__(self):
        try:
            logging.shutdown()
        except:
            pass

    def configure_logging(self):
        """
        Configure the logger based on the 'report_logger.config' file.

        Returns
        -------
            The logger.
        """
        if not logging.getLogger().hasHandlers():
            config_path = os.path.join(os.path.dirname(__file__), LOGGER_CONFIG_FILE)
            logging.config.fileConfig(fname=config_path, disable_existing_loggers=False)
        logger = logging.getLogger(LOGGER_NAME)
        return logger

    @staticmethod
    def exception_handler(func):
        @functools.wraps(func)
        def wrapper(*args, **kwargs):
            logger = logging.getLogger(LOGGER_NAME)
            try:
                run_func = func(*args, **kwargs)
                return run_func
            except grpc.RpcError as ex:
                return logger.warning(ex.details())
            except Exception as ex:
                return logger.error(str(ex))
        return wrapper
