# Copyright (c) 2022 ANSYS, Inc. - Unauthorised use, distribution or duplication is prohibited.

from ansys.report.engine.protos.report_pb2 import Section

from .report_logger import ReportLogger
from .report_title_page_and_section_base import ReportTitlePageAndSectionBase


class ReportSection(ReportTitlePageAndSectionBase):

    @ReportLogger.exception_handler
    def add_section(self, title):
        """
        Add a section.

        Parameters
        ----------
        title: str
           Title of the section

        Returns
        -------
        ReportSection
            Section created
        """
        new_section = Section()
        new_section.title = title
        new_section.parent_id.CopyFrom(self._id)
        id_of_new_section = self._report_client.AddSection(new_section)
        return ReportSection(self._report_client, id_of_new_section)

    @ReportLogger.exception_handler
    def add_texts(self, texts):
        """
        Add texts to the section.

        Texts will be separated by paragraph breaks in the report.

        Parameters
        ----------
        texts: List[str]
           List of texts.
        """
        for counter, text in enumerate(texts):
            self.add_text(text)
            if counter != len(texts) - 1:
                self.add_paragraph_break()
