# Copyright (c) 2022 ANSYS, Inc. - Unauthorised use, distribution or duplication is prohibited.

from .report_logger import ReportLogger

from ansys.report.engine.protos.report_pb2 import Text


class ReportTitlePageAndSectionBase:
    def __init__(self, client, id):
        self._report_client = client
        self._id = id

    @ReportLogger.exception_handler
    def add_text(self, text):
        """
        Add a text.

        Multiple texts added with the ``add_text()`` method are added in the same paragraph
        unless a paragraph break is enforced using the ``add_paragraph_break()`` method.

        Parameters
        ----------
        text: str
            Text to add.
        """
        proto_text = Text()
        proto_text.parent_id.CopyFrom(self._id)
        proto_text.content = text
        self._report_client.AddText(proto_text)

    @ReportLogger.exception_handler
    def add_paragraph_break(self):
        """
        Add a paragraph break.
        """
        self._report_client.AddParagraphBreak(self._id)

    @ReportLogger.exception_handler
    def add_image(self, *images):
        """
        Add one or more images.

        Parameters
        ----------
        images: ReportImage
           An arbitrary number of images to add.
        """
        for image in images:
            proto_image = image._to_proto_image(self._id)
            self._report_client.AddImage(proto_image)

    @ReportLogger.exception_handler
    def add_table(self, *tables):
        """
        Add one or more tables.

        Parameters
        ----------
        tables: ReportTable
           An arbitrary number of tables to add.
        """
        for table in tables:
            proto_table = table._to_proto_table(self._id)
            self._report_client.AddTable(proto_table)
